@@ -1,5 +1,5 @@
 /*
- * "$Id: plist.c,v 1.6.10.3 2007/05/29 01:47:28 rlk Exp $"
+ * "$Id: plist.c,v 1.17 2008/01/31 12:56:09 m0m Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -84,34 +84,37 @@ typedef struct
 
 /*
  * Generic printing system, based on SysV lp
+ *
+ * CAUTION: Do not use lpstat -t or lpstat -p.
+ * See bug 742187 (huge delays with lpstat -d -p) for an explanation.
  */
 static const print_system_t default_printing_system =
   { "SysV", N_("System V lp"), "lp -s", "-d", "-oraw", "/usr/bin/lp",
-    "/usr/bin/lpstat -v | grep -i '^device for ' | awk '{print $3}' | sed 's/://'",
+    "/usr/bin/lpstat -v | awk '/^device for /i {sub(\":\", \"\", $3); print $3}'",
   "-n" };
 
 static print_system_t known_printing_systems[] =
 {
   { "CUPS", N_("CUPS"), "lp -s", "-d", "-oraw", "/usr/sbin/cupsd",
-    "/usr/bin/lpstat -v | grep -i '^device for ' | awk '{print $3}' | sed 's/://'",
+    "/usr/bin/lpstat -v | awk '/^device for /i {sub(\":\", \"\", $3); print $3}'",
     "-n" },
   { "SysV", N_("System V lp"), "lp -s", "-d", "-oraw", "/usr/bin/lp",
-    "/usr/bin/lpstat -v | grep -i '^device for ' | awk '{print $3}' | sed 's/://'",
+    "/usr/bin/lpstat -v | awk '/^device for /i {sub(\":\", \"\", $3); print $3}'",
     "-n" },
   { "lpd", N_("Berkeley lpd (/etc/lpc)"), "lpr", "-P", "-l", "/etc/lpc",
-    "/etc/lpc status | grep '^...*:' | sed 's/:.*//'",
+    "/etc/lpc status | awk '/^...*:/ {sub(\":.*\", \"\"); print}'",
     "-#" },
   { "lpd", N_("Berkeley lpd (/usr/bsd/lpc)"), "lpr", "-P", "-l", "/usr/bsd/lpc",
-    "/usr/bsd/lpc status | grep '^...*:' | sed 's/:.*//'",
+    "/usr/bsd/lpc status | awk '/^...*:/ {sub(\":.*\", \"\"); print}'",
     "-#" },
   { "lpd", N_("Berkeley lpd (/usr/etc/lpc"), "lpr", "-P", "-l", "/usr/etc/lpc",
-    "/usr/etc/lpc status | grep '^...*:' | sed 's/:.*//'",
+    "/usr/etc/lpc status | awk '/^...*:/ {sub(\":.*\", \"\"); print}'",
     "-#" },
   { "lpd", N_("Berkeley lpd (/usr/libexec/lpc)"), "lpr", "-P", "-l", "/usr/libexec/lpc",
-    "/usr/libexec/lpc status | grep '^...*:' | sed 's/:.*//'",
+    "/usr/libexec/lpc status | awk '/^...*:/ {sub(\":.*\", \"\"); print}'",
     "-#" },
   { "lpd", N_("Berkeley lpd (/usr/sbin/lpc)"), "lpr", "-P", "-l", "/usr/sbin/lpc",
-    "/usr/sbin/lpc status | grep '^...*:' | sed 's/:.*//'",
+    "/usr/sbin/lpc status | awk '/^...*:/ {sub(\":.*\", \"\"); print}'",
     "-#" },
 };
 
@@ -208,6 +211,31 @@ stpui_build_standard_print_command(const stpui_plist_t *plist,
   return print_cmd;
 }
 
+static void
+append_external_options(char **command, const stp_vars_t *v)
+{
+  stp_string_list_t *external_options;
+  if (! command || ! *command)
+    return;
+  external_options = stp_get_external_options(v);
+  if (external_options)
+    {
+      int count = stp_string_list_count(external_options);
+      int i;
+      for (i = 0; i < count; i++)
+	{
+	  stp_param_string_t *param = stp_string_list_param(external_options, i);
+	  char *quoted_name=g_shell_quote(param->name);
+	  char *quoted_value=g_shell_quote(param->text);
+	  stp_catprintf(command, " -o%s=%s", quoted_name, quoted_value);
+	  SAFE_FREE(quoted_name);
+	  SAFE_FREE(quoted_value);
+	}
+      stp_string_list_destroy(external_options);
+    }
+}
+
+
 void
 stpui_set_printrc_file(const char *name)
 {
@@ -939,8 +967,8 @@ static void
 stpui_printrc_load_v2(FILE *fp)
 {
   int retval;
-  yyin = fp;
   char *locale;
+  yyin = fp;
 
   stpui_printrc_current_printer = NULL;
 #ifdef HAVE_LOCALE_H
@@ -1232,7 +1260,11 @@ stpui_get_system_printers(void)
   if (global_printing_system)
   {
     const char *old_locale = getenv("LC_ALL");
+    const char *old_lc_messages = getenv("LC_MESSAGES");
+    const char *old_lang = getenv("LANG");
     (void) setenv("LC_ALL", "C", 1);
+    (void) setenv("LC_MESSAGES", "C", 1);
+    (void) setenv("LANG", "C", 1);
     if ((pfile = popen(global_printing_system->scan_command, "r")) != NULL)
     {
      /*
@@ -1258,6 +1290,14 @@ stpui_get_system_printers(void)
 	setenv("LC_ALL", old_locale, 1);
       else
 	unsetenv("LC_ALL");
+      if (old_lc_messages)
+	setenv("LC_MESSAGES", old_lc_messages, 1);
+      else
+	unsetenv("LC_MESSAGES");
+      if (old_lang)
+	setenv("LANG", old_lang, 1);
+      else
+	unsetenv("LANG");
     }
   }
 }
@@ -1597,14 +1637,19 @@ stpui_print(const stpui_plist_t *printer, stpui_image_t *image)
 			}
 		      else	/* Child 2 (printer command) */
 			{
-			  const char *command;
+			  char *command;
+			  char *locale;
 			  if (stpui_plist_get_command_type(printer) ==
 			      COMMAND_TYPE_DEFAULT)
-			    command =
-			      stpui_build_standard_print_command
-			      (printer, stp_get_printer(printer->v));
+			    {
+			      command =
+				stpui_build_standard_print_command
+				(printer, stp_get_printer(printer->v));
+			      append_external_options(&command, printer->v);
+			    }
 			  else
-			    command = stpui_plist_get_custom_command(printer);
+			    command =
+			      (char *) stpui_plist_get_custom_command(printer);
 			  (void) close(2);
 			  (void) close(1);
 			  dup2 (errfd[1], 2);
@@ -1613,6 +1658,10 @@ stpui_print(const stpui_plist_t *printer, stpui_image_t *image)
 			  close (pipefd[0]);
 			  close (pipefd[1]);
 			  close(syncfd[1]);
+#ifdef HAVE_LOCALE_H
+			  locale = g_strdup(setlocale(LC_NUMERIC, NULL));
+			  setlocale(LC_NUMERIC, "C");
+#endif
 			  execl("/bin/sh", "/bin/sh", "-c", command, NULL);
 			  /* NOTREACHED */
 			  _exit (1);
@@ -1786,5 +1835,5 @@ stpui_print(const stpui_plist_t *printer, stpui_image_t *image)
 }
 
 /*
- * End of "$Id: plist.c,v 1.6.10.3 2007/05/29 01:47:28 rlk Exp $".
+ * End of "$Id: plist.c,v 1.17 2008/01/31 12:56:09 m0m Exp $".
  */
