@@ -1,5 +1,5 @@
 /*
- * "$Id: escp2-inks.c,v 1.46.10.2 2007/05/29 01:47:28 rlk Exp $"
+ * "$Id: escp2-inks.c,v 1.62 2008/02/03 03:41:43 rlk Exp $"
  *
  *   Print plug-in EPSON ESC/P2 driver for the GIMP.
  *
@@ -152,21 +152,21 @@ static const escp2_dropsize_t escp2_r300_2880_1440_dropsizes =
  * and 0x25.  The economy settings (0x10 and 0x0) don't provide any
  * bigger drops.  We get quite smooth output at 720x360 and 360 DPI, and
  * even 360x180 is surprisingly smooth.
- * Roy Harrington estimates the drop sizes are:
+ * Roy Harrington's estimates in first column; my remeasurements in second:
  *
- * 1  1.5 pl
- * 2  2.4 pl
- * 3  6.3 pl
- * 4 12   pl (rlk estimate)
- * 5 21   pl
+ * 1  1.5 pl			1.5 pl
+ * 2  2.4 pl			1.8 pl
+ * 3  6.3 pl			4.5 pl
+ * 4 12   pl (rlk estimate)	8.0 pl
+ * 5 21   pl		       11   pl (+/- 1 pl)
  */
 
 static const escp2_dropsize_t escp2_claria_720_dropsizes =
-  { "claria_720", 3, { 0.071, 0.3, 1.0 } };
+  { "claria_720", 3, { 0.125, 0.42, 1.0 } };
 static const escp2_dropsize_t escp2_claria_1440_dropsizes =
-  { "claria_1440", 3, { 0.23, 0.37, 1.0 } };
+  { "claria_1440", 3, { 0.338, 0.40, 1.0 } };
 static const escp2_dropsize_t escp2_claria_2880_dropsizes =
-  { "claria_2880", 2, { 0.62, 1.0 } };
+  { "claria_2880", 2, { 0.833, 1.0 } };
 static const escp2_dropsize_t escp2_claria_5760_dropsizes =
   { "claria_5760", 1, { 1.0 } };
 
@@ -183,13 +183,13 @@ static const escp2_dropsize_t escp2_claria_5760_dropsizes =
 */
 
 static const escp2_dropsize_t escp2_claria_1400_720_dropsizes =
-  { "claria_1400_720", 3, { 0.3, 0.57, 1.0 } };
+  { "claria_1400_720", 3, { 0.42, 0.67, 1.0 } };
 static const escp2_dropsize_t escp2_claria_1400_1440_720_dropsizes =
-  { "claria_1400_1440_720", 3, { 0.071, 0.3, 1.0 } };
+  { "claria_1400_1440_720", 3, { 0.125, 0.42, 1.0 } };
 static const escp2_dropsize_t escp2_claria_1400_1440_dropsizes =
-  { "claria_1400_1440", 3, { 0.23, 0.37, 1.0 } };
+  { "claria_1400_1440", 3, { 0.338, 0.40, 1.0 } };
 static const escp2_dropsize_t escp2_claria_1400_2880_dropsizes =
-  { "claria_1400_2880", 2, { 0.62, 1.0 } };
+  { "claria_1400_2880", 2, { 0.833, 1.0 } };
 static const escp2_dropsize_t escp2_claria_1400_5760_dropsizes =
   { "claria_1400_5760", 1, { 1.0 } };
 
@@ -235,6 +235,20 @@ static const escp2_dropsize_t escp2_3pl_pigment_c66_2880_dropsizes =
 static const escp2_dropsize_t escp2_3pl_pigment_c66_5760_dropsizes =
   { "3pl_pigment_c66_5760", 1, { 1.0 } };
 
+/* Stylus C120 */
+static const escp2_dropsize_t escp2_low_pigment_c120_dropsizes =
+  { "low_pigment_c120", 3, { 0.25, 0.5, 1.0 } };
+static const escp2_dropsize_t escp2_6pl_pigment_c120_dropsizes =
+  { "6pl_pigment_c120", 3, { 0.12, 0.3, 1.0 } };
+/*  { "6pl_pigment_c120", 3, { 0.15, 0.3, 1.0 } }; */
+/*  { "6pl_pigment_c120", 3, { 0.18, 0.333, 1.0 } }; */
+static const escp2_dropsize_t escp2_3pl_pigment_c120_dropsizes =
+  { "3pl_pigment_c120", 3, { 0.25, 0.5, 1.0 } };
+static const escp2_dropsize_t escp2_3pl_pigment_c120_2880_dropsizes =
+  { "3pl_pigment_c120_2880", 2, { 0.5, 1.0 } };
+static const escp2_dropsize_t escp2_3pl_pigment_c120_5760_dropsizes =
+  { "3pl_pigment_c120_5760", 1, { 1.0 } };
+
 /* Stylus Photo 2000P */
 static const escp2_dropsize_t escp2_2000p_dropsizes =
   { "2000p", 2, { 0.55, 1.0 } };
@@ -362,7 +376,7 @@ static const escp2_drop_list_t claria_drops =
   &escp2_claria_720_dropsizes,
   &escp2_claria_720_dropsizes,
   &escp2_claria_720_dropsizes,
-  &escp2_claria_1440_dropsizes,
+  &escp2_claria_720_dropsizes,
   &escp2_claria_1440_dropsizes,
   &escp2_claria_2880_dropsizes,
   &escp2_claria_5760_dropsizes,
@@ -375,7 +389,7 @@ static const escp2_drop_list_t claria_1400_drops =
   &escp2_claria_1400_720_dropsizes,
   &escp2_claria_1400_720_dropsizes,
   &escp2_claria_1400_1440_720_dropsizes,
-  &escp2_claria_1400_1440_dropsizes,
+  &escp2_claria_1400_1440_720_dropsizes,
   &escp2_claria_1400_1440_dropsizes,
   &escp2_claria_1400_2880_dropsizes,
   &escp2_claria_1400_5760_dropsizes,
@@ -472,6 +486,19 @@ static const escp2_drop_list_t variable_3pl_pigment_c66_drops =
   &escp2_3pl_pigment_c66_5760_dropsizes,
 };
 
+static const escp2_drop_list_t variable_3pl_pigment_c120_drops =
+{
+  &escp2_low_pigment_c120_dropsizes,
+  &escp2_low_pigment_c120_dropsizes,
+  &escp2_6pl_pigment_c120_dropsizes,
+  &escp2_6pl_pigment_c120_dropsizes,
+  &escp2_3pl_pigment_c120_dropsizes,
+  &escp2_3pl_pigment_c120_2880_dropsizes,
+  &escp2_3pl_pigment_c120_5760_dropsizes,
+  &escp2_3pl_pigment_c120_5760_dropsizes,
+  &escp2_3pl_pigment_c120_5760_dropsizes,
+};
+
 static const escp2_drop_list_t spro10000_drops =
 {
   &escp2_spro10000_dropsizes,
@@ -501,6 +528,7 @@ static const drop_list_t the_drop_lists[] =
   { "variable_3pl", &variable_3pl_drops },
   { "variable_3pl_pigment", &variable_3pl_pigment_drops },
   { "variable_3pl_pigment_c66", &variable_3pl_pigment_c66_drops },
+  { "variable_3pl_pigment_c120", &variable_3pl_pigment_c120_drops },
   { "variable_3pl_pmg", &variable_3pl_pmg_drops },
   { "variable_claria", &claria_drops },
   { "variable_claria_1400", &claria_1400_drops },
