@@ -1,5 +1,5 @@
 /*
- * "$Id: print-pcl.c,v 1.149 2008/01/26 22:00:09 rlk Exp $"
+ * "$Id: print-pcl.c,v 1.150 2008/04/26 01:15:11 rlk Exp $"
  *
  *   Print plug-in HP PCL driver for the GIMP.
  *
@@ -1049,6 +1049,19 @@ static const pcl_cap_t pcl_model_capabilities[] =
     emptylist,
     laserjet_papersources,
   },
+  /* PCL-4 with large paper */
+  { 23,
+    13 * 72, 19 * 72,
+    1, 1,				/* Min paper size */
+    PCL_RES_150_150 | PCL_RES_300_300,
+    {12, 12, 18, 18},
+    {12, 12, 10, 10},	/* Check/Fix */
+    PCL_COLOR_NONE,
+    PCL_PRINTER_LJ,
+    ljbig_papersizes,
+    emptylist,
+    laserjet_papersources,
+  },
   /* LaserJet III series */
   { 3,
     17 * 72 / 2, 14 * 72,
@@ -1062,6 +1075,19 @@ static const pcl_cap_t pcl_model_capabilities[] =
     emptylist,
     laserjet_papersources,
   },
+  /* LaserJet III series */
+  { 31,
+    17 * 72 / 2, 14 * 72,
+    1, 1,				/* Min paper size */
+    PCL_RES_150_150 | PCL_RES_300_300,
+    {12, 12, 18, 18},
+    {12, 12, 10, 10},	/* Check/Fix */
+    PCL_COLOR_NONE,
+    PCL_PRINTER_LJ | PCL_PRINTER_TIFF | PCL_PRINTER_BLANKLINE,
+    ljsmall_papersizes,
+    emptylist,
+    laserjet_papersources,
+  },
   /* Some laser printers don't have expanded A4 margins */
   { 32,
     17 * 72 / 2, 14 * 72,
@@ -1075,6 +1101,19 @@ static const pcl_cap_t pcl_model_capabilities[] =
     emptylist,
     laserjet_papersources,
   },
+  /* PCL-5 with large paper */
+  { 33,
+    13 * 72, 19 * 72,
+    1, 1,				/* Min paper size */
+    PCL_RES_150_150 | PCL_RES_300_300,
+    {12, 12, 18, 18},
+    {12, 12, 10, 10},	/* Check/Fix */
+    PCL_COLOR_NONE,
+    PCL_PRINTER_LJ | PCL_PRINTER_TIFF | PCL_PRINTER_BLANKLINE,
+    ljbig_papersizes,
+    emptylist,
+    laserjet_papersources,
+  },
   /* LaserJet 4L */
   { 4,
     17 * 72 / 2, 14 * 72,
@@ -1129,6 +1168,20 @@ static const pcl_cap_t pcl_model_capabilities[] =
     emptylist,
     laserjet_papersources,
   },
+  /* PCL-5c/5e/6/XL with large paper */
+  { 61,
+    13 * 72, 19 * 72,
+    1, 1,				/* Min paper size */
+    PCL_RES_150_150 | PCL_RES_300_300 | PCL_RES_600_600,
+    {12, 12, 18, 18},
+    {12, 12, 10, 10},	/* Check/Fix */
+    PCL_COLOR_NONE,
+    PCL_PRINTER_LJ | PCL_PRINTER_NEW_ERG | PCL_PRINTER_TIFF | PCL_PRINTER_BLANKLINE |
+      PCL_PRINTER_DUPLEX,
+    ljbig_papersizes,
+    emptylist,
+    laserjet_papersources,
+  },
   /* Some laser printers don't have expanded A4 margins */
   { 62,
     17 * 72 / 2, 14 * 72,
