@@ -1,5 +1,5 @@
 /*
- * "$Id: printers.c,v 1.79.2.1 2007/05/29 01:47:30 rlk Exp $"
+ * "$Id: printers.c,v 1.83 2008/01/21 23:34:25 rlk Exp $"
  *
  *   Print plug-in driver utility functions for the GIMP.
  *
@@ -66,6 +66,7 @@ struct stp_printer
   char       *family;           /* Printer family */
   char	     *manufacturer;	/* Printer manufacturer */
   int        model;             /* Model number */
+  int	     vars_initialized;
   const stp_printfuncs_t *printfuncs;
   stp_vars_t *printvars;
 };
@@ -209,12 +210,6 @@ stpi_get_printfuncs(const stp_printer_t *printer)
   return printer->printfuncs;
 }
 
-const stp_vars_t *
-stp_printer_get_defaults(const stp_printer_t *printer)
-{
-  return printer->printvars;
-}
-
 
 const stp_printer_t *
 stp_get_printer_by_long_name(const char *long_name)
@@ -357,7 +352,6 @@ stp_set_printer_defaults(stp_vars_t *v, const stp_printer_t *printer)
 void
 stp_initialize_printer_defaults(void)
 {
-  stp_list_item_t *printer_item;
   if (printer_list == NULL)
     {
       stpi_init_printer_list();
@@ -365,16 +359,19 @@ stp_initialize_printer_defaults(void)
 	(STP_DBG_PRINTERS,
 	 "stpi_family_register(): initialising printer_list...\n");
     }
-  printer_item = stp_list_get_start(printer_list);
-  while (printer_item)
+}
+
+const stp_vars_t *
+stp_printer_get_defaults(const stp_printer_t *printer)
+{
+  if (! printer->vars_initialized)
     {
-      stp_deprintf
-	(STP_DBG_PRINTERS, "  ==>init %s\n",
-	 ((stp_printer_t *)(stp_list_item_get_data(printer_item)))->driver);
-      set_printer_defaults
-	(((stp_printer_t *)(stp_list_item_get_data(printer_item)))->printvars, 1);
-      printer_item = stp_list_item_next(printer_item);
+      stp_printer_t *nc_printer = (stp_printer_t *) printer;
+      stp_deprintf(STP_DBG_PRINTERS, "  ==>init %s\n", printer->driver);
+      set_printer_defaults (nc_printer->printvars, 1);
+      nc_printer->vars_initialized = 1;
     }
+  return printer->printvars;
 }
 
 void
@@ -478,6 +475,17 @@ stp_end_job(const stp_vars_t *v, stp_image_t *image)
     return 1;
 }
 
+stp_string_list_t *
+stp_get_external_options(const stp_vars_t *v)
+{
+  const stp_printfuncs_t *printfuncs =
+    stpi_get_printfuncs(stp_get_printer(v));
+  if (printfuncs->get_external_options)
+    return (printfuncs->get_external_options)(v);
+  else
+    return NULL;
+}
+
 static int
 verify_string_param(const stp_vars_t *v, const char *parameter,
 		    stp_parameter_t *desc, int quiet)
@@ -727,10 +735,6 @@ stp_verify_printer_params(stp_vars_t *v)
   errbuf_t errbuf;
   stp_outfunc_t ofunc = stp_get_errfunc(v);
   void *odata = stp_get_errdata(v);
-
-  stp_dprintf(STP_DBG_VARS, v, "** Entering stp_verify_printer_params(0x%p)\n",
-	      v);
-
   stp_parameter_list_t params;
   int nparams;
   int i;
@@ -738,6 +742,9 @@ stp_verify_printer_params(stp_vars_t *v)
   int left, top, bottom, right;
   const char *pagesize = stp_get_string_parameter(v, "PageSize");
 
+  stp_dprintf(STP_DBG_VARS, v, "** Entering stp_verify_printer_params(0x%p)\n",
+	      (void *) v);
+
   stp_set_errfunc((stp_vars_t *) v, fill_buffer_writefunc);
   stp_set_errdata((stp_vars_t *) v, &errbuf);
 
@@ -837,7 +844,7 @@ stp_verify_printer_params(stp_vars_t *v)
       stp_free(errbuf.data);
     }
   stp_dprintf(STP_DBG_VARS, v, "** Exiting stp_verify_printer_params(0x%p) => %d\n",
-	      v, answer);
+	      (void *) v, answer);
   return answer;
 }
 
@@ -890,8 +897,7 @@ stp_family_register(stp_list_t *family)
       while(printer_item)
 	{
 	  printer = (const stp_printer_t *) stp_list_item_get_data(printer_item);
-	  if (!stp_list_get_item_by_name(printer_list,
-					  stp_get_driver(printer->printvars)))
+	  if (!stp_list_get_item_by_name(printer_list, printer->driver))
 	    stp_list_item_create(printer_list, NULL, printer);
 	  printer_item = stp_list_item_next(printer_item);
 	}
@@ -923,8 +929,7 @@ stp_family_unregister(stp_list_t *family)
 	{
 	  printer = (const stp_printer_t *) stp_list_item_get_data(printer_item);
 	  old_printer_item =
-	    stp_list_get_item_by_name(printer_list,
-				      stp_get_driver(printer->printvars));
+	    stp_list_get_item_by_name(printer_list, printer->driver);
 
 	  if (old_printer_item)
 	    stp_list_item_destroy(printer_list, old_printer_item);
@@ -1064,10 +1069,10 @@ stp_printvars_create_from_xmltree(stp_mxml_node_t *printer,
   outprintvars->name = sbuf;
   prop = printer->child;
   stp_deprintf(STP_DBG_XML, ">>stp_printvars_create_from_xmltree: %p, %s\n",
-	       outprintvars->printvars, outprintvars->name);
+	       (void *) (outprintvars->printvars), outprintvars->name);
   stp_fill_printvars_from_xmltree(prop, outprintvars->printvars);
   stp_deprintf(STP_DBG_XML, "<<stp_printvars_create_from_xmltree: %p, %s\n",
-	       outprintvars->printvars, outprintvars->name);
+	       (void *) (outprintvars->printvars), outprintvars->name);
   return outprintvars;
 }
 
